@@ -50,9 +50,16 @@ def log(*message, only_if=True):
 
 def process_extra_vars(extra_vars):
     for item in extra_vars:
+
+        # argparse removes quotes, just add quotes for these vars
+        if 'extra_kernel_options=' in item:
+            key, value = item.split('=', 1)
+            item = key + '="' + value + '"'
+
         if item.startswith('@'):
             # Make sure relative paths still work
             item = '@' + os.path.abspath(item[1:])
+
         yield ('-e', item)
 
 
@@ -175,12 +182,12 @@ def cmd_install(args):
             enabled_hardware_types=args.hardware_types,
             cleaning_disk_erase=args.cleaning_disk_erase,
             testing=args.testenv,
-            use_cirros=args.testenv,
+            download_custom_deploy_image=args.testenv,
             use_tinyipa=args.testenv,
             developer_mode=args.develop,
             enable_prometheus_exporter=args.enable_prometheus_exporter,
             default_boot_mode=args.boot_mode or 'uefi',
-            include_dhcp_server=not args.disable_dhcp,
+            enable_dhcp=not args.disable_dhcp,
             extra_vars=args.extra_vars,
             params_output_file=args.output,
             **kwargs)
@@ -191,7 +198,18 @@ def cmd_install(args):
         "See documentation for next steps")
 
 
+def ensure_inside_venv():
+    try:
+        import oslo_config  # noqa
+    except ImportError:
+        sys.exit("This command must be executed inside the Bifrost virtual "
+                 "environment. Try:\n"
+                 f" $ source {VENV}/bin/activate\n"
+                 " $ export OS_CLOUD=bifrost")
+
+
 def configure_inventory(args):
+    ensure_inside_venv()
     inventory = os.path.join(PLAYBOOKS, 'inventory', 'bifrost_inventory.py')
     if not args.inventory:
         os.environ['BIFROST_INVENTORY_SOURCE'] = 'ironic'
