@@ -71,6 +71,8 @@ mkdir -p ${LOG_LOCATION}/all
 sudo cp -aL /var/log/* ${LOG_LOCATION}/all/.
 sudo chown -R $USER ${LOG_LOCATION}/all
 
+[ -f /tmp/disk-image-create.log ] && sudo cp -a /tmp/disk-image-create.log ${LOG_LOCATION}
+
 sudo systemctl > ${LOG_LOCATION}/all-services.txt
 sudo journalctl -u libvirtd &> ${LOG_LOCATION}/libvirtd.log
 sudo journalctl -u ironic &> ${LOG_LOCATION}/ironic.log
@@ -109,6 +111,7 @@ sudo cp -a "/var/log/ironic-inspector/ramdisk" ${LOG_LOCATION}/inspection-ramdis
 # general info
 sudo ps auxf &> ${LOG_LOCATION}/ps.txt
 sudo lscpu > ${LOG_LOCATION}/lscpu.txt
+sudo lshw -json >  ${LOG_LOCATION}/lshw_json.txt
 # vbmc info
 sudo ${VENV}/bin/vbmc list &> ${LOG_LOCATION}/vbmc.txt
 # virsh info
